\name{HMM}
\alias{HMM}
\title{
function HMM()
}
\description{
The main function used to predict the genotype, ASE status and allelic specific ratio. 
}
\usage{
HMM(allecounts, dist, reps = 1, epsilon0 = 0.075, alpha10 = 2, 
    beta010 = 2, alpha20 = 2, beta020 = 2, maxiter = 20, cnv = NULL, 
    estimate.alpha = TRUE, common.alpha = FALSE, dist.dep = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{allecounts}{
                 An array of #SNP * 2 * #animal. Element [s, 1, a] is the allele 
                 count of the first allele for s-th SNP of the a-th animal; and element [s, 2, a] is 
                 the allele count of the second allele for s-th SNP of a-th animal a.
}
  \item{dist}{
                 A vector of length #SNP-1 for the distances between two adjacent SNP markers.
}
  \item{reps}{
                 Number of replications. Set reps=1 for real data set.
}
  \item{epsilon0}{
                 Error rate, a value between 0 and 1.
}
  \item{alpha10}{
                 Starting values for the first parameter, alpha, in beta distribution 
                 for ASE-Low rate.
}
  \item{beta010}{
                  Starting values for the second parameter, beta, in beta distribution 
                  for ASE-Low ratio.
}
  \item{alpha20}{
                  Starting values for the first parameter, alpha, in beta distribution
                  for ASE-High ratio.
}
  \item{beta020}{
                  Starting values for the second parameter, beta, in beta distribution
                  for ASE-High ratio.
}
  \item{maxiter}{
Maximum number of iteration
}
  \item{cnv}{
Convergence criterion. HMM function stops with convergence either the number of estimated 
genotype state is different with less than T*n*cnv from the last iteration or the log-likelihood
does not change. If cnv=NULL (by default), then the default value cnv=0.01. 
}
  \item{estimate.alpha}{
TRUE or FALSE. alpha1 and alpha2 are estimated by HMM function if 
estimate.alpha==TRUE.
}
  \item{common.alpha}{
TRUE or FALSE. alpha1 is set to be equal to alpha2 if common.alpha==TRUE.
}
  \item{dist.dep}{
TRUE or FALSE. The transition matrix depends on distances between adjacent SNPs 
if dist.dep==TRUE.
}
}
\value{
A list of 8. 
\item{allecounts }{The original input data. }
\item{GenoEsti }{3 dimentional array with genotype prediction result [SNP, Animal, replicate].
                 For real data, #replicate=1, so the dimension is [#SNPs, #Animals, 1].
                 1 represents homogeneous genotype carrying two alleles form the first allele, 2 represents heterozygous genotype
                 with no ASE, 3 represents heterozygous genotype with first allele ASE, 4 represents 
                 heterozygous genotype with second allele ASE, 5 represents homogeneous genotype carrying two alleles form 
                 the second allele.}
\item{Parameters }{A vector of length 31 if dist.dep=TRUE. Estimation of paramter values 
                   after convergence. These parameters includes epsilon, alpha1, beta1, alpha2, beta2, rho, and a 5 by 5 
                   transition matrix in a vector form. It is of length 30 if dist.dep=FALSE with the parameter rho deleted.}
\item{Convergence }{Returns TRUE if convergence criterion is met. FALSE if convergence criterion                    
                   is not met. }
\item{niter }{Number of iterations take.}
\item{ASEest }{The ASE ratio estimate for the ASE-High and ASE-Low SNPs.}
\item{PostdenH }{The posterior densities of ASE ratio evaluated at a list ASE ratios from 0.5 to 1, 
                 for the ASE-High SNPs.}
\item{PostdenL }{The posterior densities of ASE ratio evaluated at a list ASE ratios at from 0 to 0.5, 
                 for the ASE-Low SNPs.}
}
\references{
J. Steibel, H. Wang, P.S. Zhong (2014). A Hidden Markov Approach for Ascertaining cSNP Genotypes from RNA Sequence Data in Presence of Allelic Imbalance by Exploiting Linkage Disequilibrium.
}
\author{
J. Steibel, H. Wang, P.S. Zhong
}
\examples{
library("HMMASE")
library(R.utils)
data(total)
mbs<-membership(total,1000,2)
idid<-5


allecounts1<-total[mbs[[2]]==idid,]
allecounts<-array(0, c(nrow(allecounts1), 2, 24))
for (ani in 1:24)
{
  allecounts[,,ani]<-as.matrix(allecounts1[,c(3+ani*2, 4+ani*2)])
}

distance<-diff(allecounts1[,2])
reps<-1   
epsilon0<-0.0001 
alpha10=3
beta010=3
alpha20=3
beta020=3
maxiter=20
cnv=NULL
estimate.alpha=TRUE
common.alpha=TRUE
dist.dep=FALSE


result<-HMM(allecounts, dist=distance, reps=reps, 
epsilon0=epsilon0, alpha10=alpha10, beta010=beta010, alpha20=alpha20,
beta020=beta020, common.alpha=common.alpha, dist.dep=dist.dep)
}

